@@ -111,6 +111,7 @@ const struct ioctlstruct {
 	{ "userlut",		VIDIOCQCGUSERLUT, 	VIDIOCQCSUSERLUT,	FALSE,	flags_bool },
 	{ "retryerrors",	VIDIOCQCGRETRYERRORS,	VIDIOCQCSRETRYERRORS,	FALSE,	flags_bool },
 	{ "compatible", 	VIDIOCQCGCOMPATIBLE,	VIDIOCQCSCOMPATIBLE,	TRUE,	flags_compat },
+	{ "reg",		VIDIOCQCGSTV,		VIDIOCQCSSTV,		FALSE,	NULL },
 	{ "video_nr",		VIDIOCQCGVIDEONR,	VIDIOCQCSVIDEONR,	FALSE,	NULL },
 };
 /* }}} */
@@ -663,6 +664,25 @@ int main(int argc, char *argv[])
 						break;
 				}
 				if (i>=SIZE(ioctlinfo)) error("invalid configuration name");
+				if(!strncmp(argv[0], "reg", 3)) {
+				  int add, val;
+				  if(sscanf(argv[0], "reg%X=%X", &add, &val) == 2) {
+				    printf("set reg%X = %X", add, val);
+				    add &= 0xFFFF;
+				    add |= ((val & 0xFFFF) << 16);
+				    printf("add = %08X\n", add);
+				    r = ioctl(fd, VIDIOCQCSSTV, &add);
+				    if (r != 0) error("error\n");
+				    else printf("\n");
+				  } else if(sscanf(argv[0], "reg%X", &add) == 1) {
+				    printf("get reg%X = ", add);
+				    r = ioctl(fd, VIDIOCQCGSTV, &add);
+				    if (r != 0) error("error\n");
+				    else {
+				      printf(" %02X\n", add >> 16);
+				    }
+				  }
+				} else
 				if (argv[0][l]=='?') {
 					/* Display configuration */
 					r = ioctl(fd, ioctlinfo[i].get, &c);	if (r != 0) error("ioctl get %s", ioctlinfo[i].name);
