@@ -341,9 +341,12 @@ static inline struct urb *qc_usb_alloc_urb(int packets) { return usb_alloc_urb(p
 #define STV_REG23 		0x0423
 
 /* Maximum frame size that any sensor can deliver */
-#if 0
-#define MAX_FRAME_WIDTH		360
-#define MAX_FRAME_HEIGHT	296
+//#define TRY_HIGHRES
+#ifdef TRY_HIGHRES
+//#define MAX_FRAME_WIDTH		360
+//#define MAX_FRAME_HEIGHT	296
+#define MAX_FRAME_WIDTH		648
+#define MAX_FRAME_HEIGHT	496
 #else
 #define MAX_FRAME_WIDTH		324
 #define MAX_FRAME_HEIGHT	248
@@ -360,6 +363,7 @@ struct qc_sensor_data {
 	int height;
 	int exposure;			/* Current exposure in effect (sensor-specific value, -1=unknown) */
 	int rgain, ggain, bgain;	/* Current gains in effect (sensor-specific values, -1=unknown) */
+	int shutter;			/* Current shutter value */
 	unsigned int subsample : 1;	/* Set into subsampling mode? */
 	unsigned int compress : 1;	/* Set into compressed mode? */
 };
@@ -470,6 +474,7 @@ struct qc_adapt_data {
 	int oldexposure, exposure;
 	int gain;
 	int framecounter;
+	int shutter;
 	enum {
 		EXPCONTROL_SATURATED,	/* Picture is over/undersaturated, halve/double brightness */
 		EXPCONTROL_NEWTON,	/* Using Newton linear estimation */
@@ -486,6 +491,7 @@ struct qc_settings_data {
 	unsigned int frameskip     : 4;	/* How many frames to skip (higher=lower framerate) */
 	unsigned int quality       : 3;	/* Quality of format conversion (higher=better but slower) */
 	unsigned int adaptive      : 1;	/* Use automatic exposure control */
+	unsigned int shutter_adapt : 1;	/* Use automatic shutter control */
 	unsigned int equalize      : 1;	/* Equalize images */
 	unsigned int userlut       : 1;	/* Apply user-specified lookup-table */
 	unsigned int retryerrors   : 1;	/* If errors happen when capturing an image, retry a few times? */
@@ -541,6 +547,7 @@ struct qc_sensor {
 			/* Set primary brightness value exp (usually exposure time) and HSV 0-65535 (usually gains) */
 	int (*set_levels)(struct quickcam *qc, unsigned int exp, unsigned int gain, unsigned int hue, unsigned int sat);
 	int (*set_target)(struct quickcam *qc, unsigned int val);		/* Set target brightness for sensor autoexposure 0-65535 */
+	int (*set_shutter)(struct quickcam *qc, unsigned int val);		/* Set shutter value for sensor 0-65535 */
 	/* Exposure and gain control information */
 	Bool autoexposure;							/* Sensor has automatic exposure control */
 	int adapt_gainlow;							/* (0-65535) How eagerly to decrease gain when necessary */
